/**
 * This file is part of OpenMediaVault-autoshutdown.
 *
 * @license   http://www.gnu.org/licenses/gpl.html GPL Version 3
 * @author    Marcel Beck <marcel.beck@mbeck.org>
 * @copyright Copyright (c) 2012 Marcel Beck
 *
 * OpenMediaVault is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * OpenMediaVault is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenMediaVault. If not, see <http://www.gnu.org/licenses/>.
 */
	// require("js/omv/NavigationPanel.js")
	// require("js/omv/data/DataProxy.js")
	// require("js/omv/FormPanelExt.js")
	// require("js/omv/form/PasswordField.js")
	// require("js/omv/form/SharedFolderComboBox.js")
	// require("js/omv/form/plugins/FieldInfo.js")

	// require("js/omv/module/autoshutdown/navigation.js")
	// require("js/omv/module/autoshutdown/utils.js")

Ext.ns("OMV.Module.Services.Autoshutdown.Admin.Panel");

/**
 * @class OMV.Module.Services.Autoshutdown.Admin.Panel.Settings
 * @derived OMV.FormPanelExt
 */
OMV.Module.Services.Autoshutdown.Admin.Panel.Settings = function (config)
{
	var initialConfig = {
		rpcService  :"Autoshutdown",
		rpcGetMethod:"getSettings",
		rpcSetMethod:"setSettings"
	};
	Ext.apply(initialConfig, config);
	OMV.Module.Services.Autoshutdown.Admin.Panel.Settings.superclass.constructor.call(
					this, initialConfig);
};
Ext.extend(OMV.Module.Services.Autoshutdown.Admin.Panel.Settings, OMV.FormPanelExt, {
	getFormItems:function ()
	{
		return [
			{
				xtype   :"fieldset",
				title   :"General settings",
				defaults:{
					//				anchor: "100%",
					labelSeparator:""
				},
				items   :[
					{
						xtype     :"checkbox",
						name      :"enable",
						fieldLabel:"Enable",
						checked   :false,
						inputValue:1
					},
					{
						xtype     :"numberfield",
						name      :"flag",
						fieldLabel:"Flag",
						vtype     :"autoshutdown_flag",
						value     :6,
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Set the number of total failures before shutdown."
					},
					{
						xtype     :"numberfield",
						name      :"sleep",
						fieldLabel:"Sleep",
						vtype     :"autoshutdown_sleep",
						value     :180,
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Numbers of seconds between each check/loop."
					},
					{
						xtype   :"fieldset",
						title   :"Up Hours",
						defaults:{
							labelSeparator:""
						},
						items   :[
							{
								xtype     :"checkbox",
								name      :"checkclockactive",
								fieldLabel:"Check Clock",
								checked   :false,
								inputValue:1,
								plugins   :[ OMV.form.plugins.FieldInfo ],
								infoText  :"Check Clock to identify uptime."
							},
							{
								xtype     :"compositefield",
								name      :"uphours",
								fieldLabel:"Hours",
								width     :200,
								items     :[
									{
										xtype        :"combo",
										name         :"uphours-begin",
										mode         :"local",
										store        :Array.range(0, 23),
										allowBlank   :false,
										editable     :false,
										triggerAction:"all",
										width        :50,
										value        :6,
										reset        :function ()
										{
										}
									},
									{
										xtype:"displayfield",
										value:".."
									},
									{
										xtype        :"combo",
										name         :"uphours-end",
										mode         :"local",
										store        :Array.range(0, 23),
										allowBlank   :false,
										editable     :false,
										triggerAction:"all",
										width        :50,
										value        :20,
										reset        :function ()
										{
										}
									}
								]
							}
						]
					},
					{
						xtype   :"fieldset",
						title   :"Experts",
						defaults:{
							labelSeparator:""
						},
						items   :[
							{
								xtype     :"checkbox",
								name      :"syslog",
								fieldLabel:"Log to Syslog",
								checked   :true,
								inputValue:1,
								plugins   :[ OMV.form.plugins.FieldInfo ],
								infoText  :"Write log informations to system logs."
							},
							{
								xtype     :"checkbox",
								name      :"verbose",
								fieldLabel:"Verbose",
								checked   :true,
								inputValue:1,
								plugins   :[ OMV.form.plugins.FieldInfo ],
								infoText  :"Verbose mode."
							},
							{
								xtype     :"checkbox",
								name      :"fake",
								fieldLabel:"Fake",
								checked   :true,
								inputValue:1,
								plugins   :[ OMV.form.plugins.FieldInfo ],
								infoText  :"Fake mode."
							},
							{
								xtype     :"textfield",
								name      :"extraoptions",
								fieldLabel:"Extra options",
								allowBlank:true,
								autoCreate:{
									tag         :"textarea",
									autocomplete:"off",
									rows        :"3",
									cols        :"65"
								},
								plugins   :[ OMV.form.plugins.FieldInfo ],
								infoText  :'<a href="https://github.com/OMV-Plugins/autoshutdown/blob/master/src/README" target="_blank">README</a>'
							}
						]
					}
				]
			}
		];
	}
});

OMV.NavigationPanelMgr.registerPanel("services", "autoshutdown", {
	cls     :OMV.Module.Services.Autoshutdown.Admin.Panel.Settings,
	title   :"Settings",
	position:10
});